<!-- markdownlint-disable -->

<a href="..\..\qtstrap\utils\timestamp.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.timestamp`





---

<a href="..\..\qtstrap\utils\timestamp.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `time_since`

```python
time_since(timestamp)
```






---

<a href="..\..\qtstrap\utils\timestamp.py#L8"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `TimeStamp`




<a href="..\..\qtstrap\utils\timestamp.py#L9"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `TimeStamp.__init__`

```python
__init__()
```








---

<a href="..\..\qtstrap\utils\timestamp.py#L12"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `TimeStamp.time_since`

```python
time_since(timestamp=None)
```





---

<a href="..\..\qtstrap\utils\timestamp.py#L21"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `TimeStamp.update`

```python
update()
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
